@@ -1,4 +1,4 @@
-/* $Id: gdict-pref.c,v 1.32 2005/09/23 14:34:39 vnoel Exp $ */
+/* $Id: gdict-pref.c,v 1.33 2005/10/21 15:20:40 kmaraas Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -242,8 +242,8 @@ gdict_pref_load (GDictWindow *gdict, GDictPref *pref)
   pref->dfl_strat = gdict_get_gconf_string (gdict, "strategy");
   gdict_add_gconf_notify (gdict, "strategy", strat_changed_cb, gdict);
 
-	/* FIXME : we need to listen to these keys and react to changes */
-	pref->fontname = gdict_get_gconf_string (gdict, "fontname");
+  /* FIXME : we need to listen to these keys and react to changes */
+  pref->fontname = gdict_get_gconf_string (gdict, "fontname");
     
   /* If things go bad and gconf doesn't return values, we shouldn't die so just return the 
      default schemas */
@@ -282,5 +282,8 @@ gdict_pref_destroy (GDictPref *pref)
   if (pref->dfl_strat != NULL)
     g_free (pref->dfl_strat);
 
+  if (pref->fontname != NULL)
+    g_free (pref->fontname);
+
   g_free (pref);
 }
