@@ -24,17 +24,76 @@
 #include "info.h"
 #include "misc.h"
 
-static void RepaintLogInfo (LogviewWindow *window, GtkWidget *label);
-static void QuitLogInfo (GtkWidget *widget, gpointer data);
-static void CloseLogInfo (GtkWidget *widget, int arg, gpointer data);
+#define MAX_DAY_STRING 512
 
-/* ----------------------------------------------------------------------
-   NAME:          LogInfo
-   DESCRIPTION:   Display the statistics of the log.
-   ---------------------------------------------------------------------- */
+static void
+loginfo_repaint (LogviewWindow *window, GtkWidget *label)
+{
+   char *utf8;
+   Day *day;
+   gchar day_string[MAX_DAY_STRING];
+   Log *log;
+   gchar *info_string, *size, *modified, *start_date, *last_date, *num_lines, *tmp, *size_tmp;
+   
+   g_return_if_fail (LOGVIEW_IS_WINDOW (window));
+
+   log = window->curlog;
+   if (log==NULL)
+	   return;
+   
+   tmp = gnome_vfs_format_file_size_for_display (window->curlog->lstats->size);
+   size_tmp = g_strdup_printf (_("<b>Size</b>: %s"), tmp);
+   size = LocaleToUTF8 (size_tmp);
+   g_free (size_tmp);
+   g_free (tmp);
+   
+   tmp = g_strdup_printf (_("<b>Modified</b>: %s"), ctime (&(window->curlog->lstats->mtime)));
+   modified = LocaleToUTF8 (tmp);
+   g_free (tmp);
+   
+   day = g_list_first (log->days)->data;
+   g_date_strftime (day_string, MAX_DAY_STRING, ("%x"), day->date);
+   tmp = g_strdup_printf(_("<b>Start Date</b>: %s"), day_string);
+   start_date = LocaleToUTF8 (tmp);
+   g_free (tmp);
+   
+   day = g_list_last (log->days)->data;
+   g_date_strftime (day_string, MAX_DAY_STRING, ("%x"), day->date);
+   tmp = g_strdup_printf(_("<b>Last Date</b>: %s"), day_string);
+   last_date = LocaleToUTF8 (tmp);
+   g_free (tmp);
+   
+   tmp = g_strdup_printf(_("<b>Number of Lines</b>: %ld"), window->curlog->total_lines);
+   num_lines = LocaleToUTF8 (tmp);
+   g_free (tmp);
+   
+   info_string = g_strdup_printf ("%s\n%s%s\n%s\n%s", size, modified, start_date, last_date, num_lines);
+   g_free (size);
+   g_free (modified);
+   g_free (start_date);
+   g_free (last_date);
+   g_free (num_lines);
+
+   gtk_label_set_markup (GTK_LABEL (label), info_string);
+   g_free (info_string);
+}
+
+static void
+loginfo_quit (GtkWidget *widget, gpointer data)
+{
+   LogviewWindow *window = data;
+   gtk_widget_hide (widget);
+   window->loginfovisible = FALSE;
+}
+
+static void
+loginfo_close (GtkWidget *widget, int arg, gpointer data)
+{
+   loginfo_quit (widget, data);
+}
 
 void
-LogInfo (GtkAction *action, GtkWidget *callback_data)
+loginfo_new (GtkAction *action, GtkWidget *callback_data)
 {
 	static GtkWidget *label;
 	static GtkWidget *info_dialog;
@@ -51,10 +110,10 @@ LogInfo (GtkAction *action, GtkWidget *callback_data)
 							  NULL);
 		
 		g_signal_connect (G_OBJECT (info_dialog), "response",
-				  G_CALLBACK (CloseLogInfo),
+				  G_CALLBACK (loginfo_close),
 				  window);
 		g_signal_connect (GTK_OBJECT (info_dialog), "destroy",
-				  G_CALLBACK (QuitLogInfo),
+				  G_CALLBACK (loginfo_quit),
 				  window);
 		g_signal_connect (GTK_OBJECT (info_dialog), "delete_event",
 				  G_CALLBACK (gtk_true),
@@ -73,76 +132,7 @@ LogInfo (GtkAction *action, GtkWidget *callback_data)
 		
 	}
 
-	RepaintLogInfo (window, label);
+	loginfo_repaint (window, label);
 	gtk_widget_show_all (info_dialog);
 	window->loginfovisible = TRUE;
 }
-
-/* ----------------------------------------------------------------------
-   NAME:          RepaintLogInfo
-   DESCRIPTION:   Repaint the log info window.
-   ---------------------------------------------------------------------- */
-
-static void
-RepaintLogInfo (LogviewWindow *window, GtkWidget *label)
-{
-   char *utf8;
-   gchar *info_string, *size, *modified, *start_date, *last_date, *num_lines, *tmp;
-   
-   if (!window->curlog)
-	   return;
-   
-   tmp = g_strdup_printf(_("<b>Size</b>: %ld bytes"), (long) window->curlog->lstats.size);
-   size = LocaleToUTF8 (tmp);
-   g_free (tmp);
-   
-   tmp = g_strdup_printf (_("<b>Modified</b>: %s"), ctime (&(window->curlog)->lstats.mtime));
-   modified = LocaleToUTF8 (tmp);
-   g_free (tmp);
-   
-   tmp = g_strdup_printf(_("<b>Start Date</b>: %s"), ctime (&(window->curlog)->lstats.startdate));
-   start_date = LocaleToUTF8 (tmp);
-   g_free (tmp);
-   
-   tmp = g_strdup_printf(_("<b>Last Date</b>: %s"), ctime (&(window->curlog)->lstats.enddate));
-   last_date = LocaleToUTF8 (tmp);
-   g_free (tmp);
-   
-   tmp = g_strdup_printf(_("<b>Number of Lines</b>: %ld"), window->curlog->lstats.numlines);
-   num_lines = LocaleToUTF8 (tmp);
-   g_free (tmp);
-   
-   info_string = g_strdup_printf ("%s\n%s%s%s%s", size, modified, start_date, last_date, num_lines);
-   
-   g_free (size);
-   g_free (modified);
-   g_free (start_date);
-   g_free (last_date);
-   g_free (num_lines);
-
-   gtk_label_set_markup (GTK_LABEL (label), info_string);
-
-   g_free (info_string);
-}
-
-/* ----------------------------------------------------------------------
-   NAME:          CloseLogInfo
-   DESCRIPTION:   Callback called when the log info window is closed.
-   ---------------------------------------------------------------------- */
-
-static void
-CloseLogInfo (GtkWidget *widget, int arg, gpointer data)
-{
-   LogviewWindow *window = data;
-   gtk_widget_hide (widget);
-   window->loginfovisible = FALSE;
-}
-
-static void
-QuitLogInfo (GtkWidget *widget, gpointer data)
-{
-   LogviewWindow *window = data;
-   gtk_widget_hide (widget);
-   window->loginfovisible = FALSE;
-}
-
